@@ -28,7 +28,7 @@ FontManager::~FontManager()
 void FontManager::reload( void)
 {
     XTRACE();
-    hash_map< string, GLBitmapFont*, hash<string> >::const_iterator ci;
+    hash_map< const string, GLBitmapFont*, hash<const string> >::const_iterator ci;
     for( ci=_resourceMap.begin(); ci!=_resourceMap.end(); ci++)
     {
 	GLBitmapFont *font = ci->second;
