@@ -23,7 +23,7 @@
 #include <GLBitmapFont.hpp>
 #include <GLBitmapCollection.hpp>
 
-#include <tinyxml/tinyxml.h>
+#include <tinyxml.h>
 
 class Selectable
 {
@@ -130,6 +130,23 @@ protected:
 
 class ResolutionSelectable:public TextOnlySelectable
 {
+    struct Resolution
+    {
+	Resolution( int w, int h):width(w), height(h) {}
+	Resolution( int w, int h, string t):width(w), height(h), text(t) {}
+	int width;
+	int height;
+	string text;
+	bool operator==(Resolution &r1)
+	{
+	    return (r1.width=width) && (r1.height==height);
+	}
+	bool operator!=(Resolution &r1)
+	{
+	    return ! operator==(r1);
+	}
+    };
+
 public:
     ResolutionSelectable( 
         const BoundingBox &r, 
@@ -142,12 +159,14 @@ public:
     void activate( void);
 
 protected:
+    void addFullscreenResolutions(void);
+
     GLBitmapFont *_fontShadow;
     BoundingBox _bRect;
     int _checkmark;
     int _checkmarkOff;
-    list<string> _resolutionList;
-    list<string>::iterator _activeResolution;
+    list<Resolution> _resolutionList;
+    list<Resolution>::iterator _activeResolution;
 };
 
 class FloatSelectable:public TextOnlySelectable
@@ -158,7 +177,8 @@ public:
 	const string &text,
 	const string &info, 
 	const string &variable,
-	const string &range);
+	const string &range,
+	const string &sliderOffset);
 
     virtual void input( const Trigger &trigger, const bool &isDown);
     virtual void draw( void);
@@ -175,6 +195,7 @@ protected:
 
     int _slider;
     int _doubleArrow;
+    int _sliderOffset;
 };
 
 class EnumSelectable:public TextOnlySelectable
