@@ -13,7 +13,9 @@
 // FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details
 //
 #include <stdlib.h>
+#ifndef VCPP
 #include <unistd.h>
+#endif
 #include <sys/stat.h>
 #include <sys/types.h>
 
@@ -23,10 +25,12 @@
 #include <ResourceManager.hpp>
 #include <Tokenizer.hpp>
 
-const string CONFIG_DEFAULT_FILE1 = "config.txt";
+const string CONFIG_DEFAULT_FILE = "config.txt";
 
 Config::Config( void):
-    _defaultConfigFileName(".critter")
+    _defaultConfigFileName(CONFIG_DEFAULT_FILE),
+    _subdir(""),
+    _configDirectory("")
 {
     XTRACE();
 }
@@ -63,38 +67,37 @@ void Config::getConfigItemList( list<ConfigItem> &ciList)
 
 const string &Config::getConfigFileName( void)
 {
-    struct stat statInfo;
     static string configFile;
+    if( configFile != "" ) return configFile;
+
     getString( CONFIGFILE, configFile);
 
-    static string CONFIG_DEFAULT_FILE2 = _defaultConfigFileName;
-
+    struct stat statInfo;
     //does explicitly given config file exist?
     if( configFile == "")
     {
-	if( (stat( CONFIG_DEFAULT_FILE1.c_str(), &statInfo) != -1) )
+	if( (stat( _defaultConfigFileName.c_str(), &statInfo) != -1) )
 	{
 	    //local config.txt exists -> OK
-	    return CONFIG_DEFAULT_FILE1;
+	    return _defaultConfigFileName;
 	}
 
-	if( (stat( CONFIG_DEFAULT_FILE2.c_str(), &statInfo) != -1) )
+	configFile = _defaultConfigFileName;
+
+	if( _subdir != "")
 	{
-	    //local .file exists -> OK
-	    return CONFIG_DEFAULT_FILE2;
+	    _configDirectory = _subdir + "/";
+	    configFile = _configDirectory + configFile;
 	}
 
-#ifdef WIN32
-	configFile = CONFIG_DEFAULT_FILE1;
-#else
+#ifndef WIN32
 	const char * home = getenv("HOME");
 	if( home)
 	{
-	    configFile = home;
-	    configFile += "/" + CONFIG_DEFAULT_FILE2;
+	    _configDirectory = home + string("/") + _configDirectory;
+	    configFile = home + string("/") + configFile;
 	}
 #endif
-
     }
     else
     {
@@ -103,17 +106,23 @@ const string &Config::getConfigFileName( void)
 	    //local config exists -> OK
 	    return configFile;
 	}
+
+	if( _subdir != "")
+	{
+	    _configDirectory = _subdir + "/";
+	    configFile = _configDirectory + configFile;
+	}
+
 #ifndef WIN32
 	const char * home = getenv("HOME");
 	if( home)
 	{
-	    string homeConfig = home;
-	    homeConfig += "/" + configFile;
+	    string homeConfig = home + string("/") + configFile;
 	    if( (stat( homeConfig.c_str(), &statInfo) != -1) )
 	    {
+		_configDirectory = home + string("/") + _configDirectory;
 		//home config exists -> OK
 		configFile = homeConfig;
-		return configFile;
 	    }
 	}
 #endif
@@ -130,11 +139,22 @@ void Config::updateFromCommandLine( int argc, char *argv[])
         if( (argv[i][0] == '+') && ((i+1)<argc))
         {
             updateKeyword( &argv[i][1], argv[i+1]);
+	    i++;
         }
         if( (argv[i][0] == '-') && ((i+1)<argc))
         {
-            updateTransitoryKeyword( &argv[i][1], argv[i+1]);
+	    if( (argv[i+1][0] != '-') && (argv[i+1][0] != '+'))
+	    {
+		updateTransitoryKeyword( &argv[i][1], argv[i+1]);
+		i++;
+	    }
+	    else
+		updateTransitoryKeyword( &argv[i][1], "true");
         }
+	else if( (argv[i][0] == '-'))
+	{
+            updateTransitoryKeyword( &argv[i][1], "true");
+	}
     }
 }
 
@@ -143,7 +163,7 @@ void Config::updateFromFile( void)
     XTRACE();
 
     const string configFile = getConfigFileName();
-//    LOG_INFO << "Updating Configuration from : " << configFile << endl;
+    LOG_INFO << "Updating Configuration from : " << configFile << endl;
 
     if( !ResourceManagerS::instance()->selectResource( configFile))
     {
