@@ -19,12 +19,11 @@
 class WPP
 {
 public:
-    WPP( float period = 1.0);
+    WPP( float period = 1.0f);
     void Update( void);
     float GetCountPerPeriod( void){ return _cpp;}
 
 private:
-    WPP( void);
     WPP( const WPP&);
     WPP &operator=(const WPP&);
 
