@@ -21,23 +21,25 @@ using namespace std;
 
 namespace HASH_NAMESPACE
 {
-    struct hash<const string>
+    template<>
+	struct hash<const string>
     {
 	//a simple hash function for string
 	int operator()(const string & s) const
 	{
-	    int hashval = 13*s.size() + 5*s[s.size()/2];
+	    int hashval = 13*(int)s.size() + 5*s[(int)s.size()/2];
     //        cout << "  > Hash of " << s << " = " << hashval << endl;
 	    return hashval;
 	}
     };
 
-    struct hash<string>
+    template<>
+	struct hash<string>
     {
 	//a simple hash function for string
 	int operator()(string s) const
 	{
-	    int hashval = 13*s.size() + 5*s[s.size()/2];
+	    int hashval = 13*(int)s.size() + 5*s[(int)s.size()/2];
     //        cout << "  > Hash of " << s << " = " << hashval << endl;
 	    return hashval;
 	}
