@@ -108,9 +108,9 @@ struct Point3D
 
     inline Point3D &operator=( const Point3Di &pi)
     {
-	x = pi.x;
-	y = pi.y;
-	z = pi.z;
+	x = (float)pi.x;
+	y = (float)pi.y;
+	z = (float)pi.z;
 	return *this;
     }
 };
@@ -184,13 +184,18 @@ inline Point3D cross( const Point3D p1, const Point3D p2)
 		p1.x*p2.y-p1.y*p2.x));
 }
 
+inline float dist(const Point3D &p)
+{
+    return sqrt(p.x*p.x + p.y*p.y + p.z*p.z);
+}
+
 inline void norm( Point3D &p)
 {
-    float dist = sqrt(p.x*p.x + p.y*p.y + p.z*p.z);
+    float d = dist(p);
 
-    p.x = p.x/dist;
-    p.y = p.y/dist;
-    p.z = p.z/dist;
+    p.x = p.x/d;
+    p.y = p.y/d;
+    p.z = p.z/d;
 }
 
 inline void Clamp( float &val, const float &MINval, const float &MAXval)
@@ -235,15 +240,38 @@ struct vec3
 
     vec3( float X, float Y, float Z):x(v[0]),y(v[1]),z(v[2]) { x=X; y=Y; z=Z;}
 
+    vec3(const vec3 &vi):x(v[0]),y(v[1]),z(v[2]) 
+    {
+	v[0]=vi.x; 
+	v[1]=vi.y; 
+	v[2]=vi.z; 
+    }
+
     vec3 &operator=(const vec3 &vi)
     {
-	x=vi.x; 
-	y=vi.y; 
-	z=vi.z; 
+	v[0]=vi.x; 
+	v[1]=vi.y; 
+	v[2]=vi.z; 
+
 	return *this;
     }
 };
 
+inline vec3 operator+( const vec3 p1, const vec3 p2)
+{
+    return( vec3( p1.x+p2.x, p1.y+p2.y, p1.z+p2.z));
+}
+
+inline vec3 operator-( const vec3 p1, const vec3 p2)
+{
+    return( vec3( p1.x-p2.x, p1.y-p2.y, p1.z-p2.z));
+}
+
+inline vec3 operator*( const vec3 p1, const float s)
+{
+    return( vec3( p1.x*s, p1.y*s, p1.z*s));
+}
+
 //-----------------------------------------------------------------------
 
 #endif
