@@ -18,7 +18,17 @@
 #include <gl++.hpp>
 #include <SDL/SDL_image.h>
 
-class GLTexture
+class GLTextureI
+{
+public:
+    virtual void bind( void) = 0;
+    virtual void unbind( void) = 0;
+    virtual void reload( void) = 0;
+
+    virtual ~GLTextureI() {}
+};
+
+class GLTexture : public GLTextureI
 {
 public:
     //target: GL_TEXTURE_1D, GL_TEXTURE_2D, GL_TEXTURE_CUBE_MAP_ARB, etc.
